@@ -1,20 +1,21 @@
+# -*- encoding: utf-8 -*-
+
 from __future__ import print_function
 
-from itertools import islice
 import json
 import os
 import os.path as osp
 import re
 import sys
 import textwrap
+from itertools import islice
 
-from bs4 import BeautifulSoup
 import requests
+from bs4 import BeautifulSoup
 
 from .download import download
 from .download import indent
 
-
 client = requests.session()
 
 folders_url = "https://drive.google.com/drive/folders/"
@@ -351,7 +352,7 @@ def download_folder(
 
         filename = download(
             files_url + file_id,
-            output=str(file_path),
+            output=file_path,
             quiet=quiet,
             proxy=proxy,
             speed=speed,
